'' +--------------------------------------------------------------------------+
'' | ......OS   An Operating System for the Propeller Chip                    |
'' +--------------------------------------------------------------------------+
'' |                     HARDWARE DEFINITIONS                                 |
'' +--------------------------------------------------------------------------+
'' |  License            MIT License                                          |
'' +--------------------------------------------------------------------------+
'' RR20100216   Separate file: by Cluso99
'' RR20100217
'' RR20100221   TriBlade#2 change TV & Kbdata pins (SD conflict)
'' RR20120304   RamBlade/TriBlade#2/RamBlade3 hardware definitions

CON
'select the hardware option...
  _xinfreq = 6_500_000
' _clkfreq = 104_000_000
  _clkmode = xtal1 + pll16x

  _siPin        = 31            'serial
  _soPin        = 30
  _baud         = 115200
  _siRB1        = 23            'RamBlade SI/kbdData
  _soRB1        = 22            'RamBlade SO/tvPins
  _screenrows   = 20            'for 1pinTV


{------------------------------------------------------------------------------
' For KyeDos3
  _SD_WP        = -1            ' -1 ifnot installed.
  _SD_CD        = -1            ' -1 ifnot installed.
  _RTC_DAT      = -1            ' -1 ifnot installed.
  _RTC_CLK      = -1            ' -1 ifnot installed.

  _VGA_Enabled = false 'true ' VGA display on
  _VGA_PinGroup = -1   '2

  _LCD_Enabled = false 'true ' false or true for 20x4 LCD display

  _Serial_Enabled = true ' send output to serial port 

  _KBD_Enabled = false 'true ' Keyboard on
  _KBD_PinGroup = -1   '26

  _leftChannelVolume = 32
  _rightChannelVolume = 32

  _leftChannelAudioPin = -1 ' -1 ifnot installed.
  _rightChannelAudioPin = -1 ' -1 ifnot installed.

  _leftMicFeedBackPin = -1 ' -1 ifnot installed.
  _leftMicInputPin = -1 ' -1 ifnot installed.

  _rightMicFeedBackPin = -1 ' -1 ifnot installed.
  _rightMicInputPin = -1 ' -1 ifnot installed.
------------------------------------------------------------------------------}
  













{
'Hybrid
'========
  _xinfreq = 6_000_000        
  _clkfreq = 96_000_000        
  _clkmode = xtal1 + pll16x

  rxPin  = 31                                           'serial
  txPin  = 30
  baud   = 115200
  serPins = txPin << 8 | rxPin

  kdPin  = 12                                           'PS2 keyboard 
  kcPin  = 13
  ktime  = 0
  kbdPar = ktime << 16 | kcPin << 8 | kdpin

  tvPina = 24                                           'TV
  tvPinb = 25
  tvPinc = 26
  tvPind = 27
  tvPins = tvPind << 24 | tvPinc << 16 | tvPinb << 8 | tvPina 

  spiDO  = 8                                            'SD pins
  spiClk = 9
  spiDI  = 10
  spiCS  = 11
  sdPins = spiCS << 24 | spiDI << 16 | spiClk << 8 | spiDO
}

{
'Hydra
'========
  _xinfreq = 10_000_000        
  _clkfreq = 80_000_000        
  _clkmode = xtal1 + pll8x

  rxPin  = 31                                           'serial
  txPin  = 30
  baud   = 115200
  serPins = txPin << 8 | rxPin

  kdPin  = 13                                           'PS2 keyboard 
  kcPin  = 12
  ktime  = 0
  kbdPar = ktime << 16 | kcPin << 8 | kdpin

  tvPina = 24                                           'TV
  tvPinb = 25
  tvPinc = 26
  tvPind = 27
  tvPins = tvPind << 24 | tvPinc << 16 | tvPinb << 8 | tvPina 

  spiDO  = 16                                           'SD pins
  spiClk = 17
  spiDI  = 18
  spiCS  = 19
  sdPins = spiCS << 24 | spiDI << 16 | spiClk << 8 | spiDO
}


{
'Demo/proto
'==========
  _xinfreq = 5_000_000
  _clkfreq = 80_000_000        
  _clkmode = xtal1 + pll16x

  rxPin  = 31                                           'serial
  txPin  = 30
  baud   = 115200
  serPins = txPin << 8 | rxPin

  kdPin  = 26                                           'PS2 keyboard 
  kcPin  = 27
  ktime  = 0
  kbdPar = ktime << 16 | kcPin << 8 | kdpin

  tvPina = 12                                           'TV
  tvPinb = 13
  tvPinc = 14
  tvPind = 15
  tvPins = tvPind << 24 | tvPinc << 16 | tvPinb << 8 | tvPina 

  spiDO  = 0                                            'SD pins
  spiClk = 1
  spiDI  = 2
  spiCS  = 3
  sdPins = spiCS << 24 | spiDI << 16 | spiClk << 8 | spiDO
}
{
'TriBlade#2
'==========
'  _xinfreq = 5_000_000        
'  _clkfreq = 80_000_000        
'  _xinfreq = 6_000_000        
  _clkfreq = 96_000_000        
  _clkmode = xtal1 + pll16x

  rxPin  = 31                                           'serial
  txPin  = 30
  baud   = 115200
  serPins = txPin << 8 | rxPin

  kdPin  = 13                   '26                     '1-pin PS2 keyboard
  kcPin  = -1 & $FF             '27                     'not used
' ktime  = 6300
  ktime  = 7600  '(6MHz xtal)
  kbdPar = ktime << 16 | kcPin << 8 | kdpin

  tvPina = -1 & $FF             '12                     'not used
  tvPinb = -1 & $FF             '13                     'not used
  tvPinc = 12                   '14                     'best for 1-pin TV
  tvPind = -1 & $FF             '15                     'not used
  tvPins = tvPind << 24 | tvPinc << 16 | tvPinb << 8 | tvPina 

  spiDO  = 9                                            'SD pins
  spiClk = 28
  spiDI  = 8
  spiCS  = 14
  sdPins = spiCS << 24 | spiDI << 16 | spiClk << 8 | spiDO
}

{
'RamBlade
'========
' _xinfreq = 6_500_000
'  _clkfreq = 96_000_000        '6MHz
  _clkfreq = 104_000_000
  _clkmode = xtal1 + pll16x

  rxPin  = 23                     'serial               ' \ same as KBD & TV pins !
  txPin  = 22                                           ' /
  baud   = 115200
  serPins = txPin << 8 | rxPin

  kdPin  = 23                                           '1-pin PS2 keyboard
  kcPin  = -1 & $FF                                     'not used
  ktime  = 8200
  kbdPar = ktime << 16 | kcPin << 8 | kdpin

  tvPina = -1 & $FF                                     'not used
  tvPinb = -1 & $FF                                     'not used
  tvPinc = 22                                           'best for 1-pin TV
  tvPind = -1 & $FF
  tvPins = tvPind << 24 | tvPinc << 16 | tvPinb << 8 | tvPina 

  spiDO  = 24                                           'SD pins
  spiClk = 26
  spiDI  = 25
  spiCS  = 19
  sdPins = spiCS << 24 | spiDI << 16 | spiClk << 8 | spiDO
}

PUB dummy